package org.foxarmy.barcodescannerforemployees

import android.content.Context
import android.database.sqlite.SQLiteDatabase
import android.database.sqlite.SQLiteOpenHelper
import android.provider.BaseColumns

object ProductContract {
    object ProductEntry : BaseColumns {
        const val TABLE_NAME = "products"
        const val PRODUCT_NAME = "name"
        const val PRODUCT_NET_WEIGHT = "net_weight"
        const val IMAGE_FILENAME = "image_filename"
    }
}

object ShelfContract {
    object ShelfEntry : BaseColumns {
        const val TABLE_NAME = "shelf"
        const val PRODUCT_ID = "product_id"
        const val EXPIRE_DATE = "expire_date"
    }
}

object CategoriesContract {
    object CategoryEntry : BaseColumns {
        const val TABLE_NAME = "categories"
        const val CATEGORY_NAME = "category_name"
    }
}

const val SQL_CREATE_PRODUCT_TABLE =
    "CREATE TABLE ${ProductContract.ProductEntry.TABLE_NAME} (" +
            "${BaseColumns._ID} INTEGER PRIMARY KEY," +
            "${ProductContract.ProductEntry.PRODUCT_NAME} TEXT," +
            "${ProductContract.ProductEntry.PRODUCT_NET_WEIGHT} REAL," +
            "${ProductContract.ProductEntry.IMAGE_FILENAME} TEXT)"

const val SQL_CREATE_SHELF_TABLE =
    "CREATE TABLE ${ShelfContract.ShelfEntry.TABLE_NAME} (" +
        "${ShelfContract.ShelfEntry.PRODUCT_ID} INTEGER," +
        "${ShelfContract.ShelfEntry.EXPIRE_DATE} DATE)"

const val SQL_CREATE_CATEGORIES_TABLE =
    "CREATE TABLE ${CategoriesContract.CategoryEntry.TABLE_NAME} (" +
            "${CategoriesContract.CategoryEntry.CATEGORY_NAME} TEXT)"

class DBStorageController(context: Context) : SQLiteOpenHelper(context, DATABASE_NAME, null, DATABASE_VERSION) {

    override fun onCreate(db: SQLiteDatabase) {
        db.execSQL(SQL_CREATE_PRODUCT_TABLE)
        db.execSQL(SQL_CREATE_SHELF_TABLE)
        db.execSQL(SQL_CREATE_CATEGORIES_TABLE)
    }

    override fun onUpgrade(p0: SQLiteDatabase?, p1: Int, p2: Int) {
        TODO("Not yet implemented")
    }

    companion object {
        // If you change the database schema, you must increment the database version.
        const val DATABASE_VERSION = 1
        const val DATABASE_NAME = "database.db"
    }
}